@@ -1,5 +1,5 @@
 """Python client lib for Solarfocus"""
-__version__ = "2.0.2"
+__version__ = "2.0.3"
 
 import logging
 from enum import Enum
@@ -61,7 +61,7 @@ class SolarfocusAPI:
 
     @property
     def hc1_target_temperatur(self) -> float:
-        return self.heating_circuit.target_supply_temperature.scaled_value
+        return self.heating_circuit.target_supply_temperature.reverse_scaled_value
 
     @property
     def hc1_cooling(self) -> int:
@@ -73,7 +73,7 @@ class SolarfocusAPI:
 
     @property
     def hc1_target_room_temperatur(self) -> float:
-        return self.heating_circuit.target_room_temperatur.scaled_value
+        return self.heating_circuit.target_room_temperatur.reverse_scaled_value
 
     @property
     def hc1_indoor_temperature_external(self) -> float:
@@ -117,7 +117,7 @@ class SolarfocusAPI:
 
     @property
     def bo1_target_temperatur(self) -> float:
-        return self.boiler.target_temperature.scaled_value
+        return self.boiler.target_temperature.reverse_scaled_value
 
     @property
     def bo1_single_charge(self) -> int:
@@ -222,7 +222,7 @@ class SolarfocusAPI:
 
     @property
     def hp_outdoor_temperature_external(self) -> float:
-        return self.heatpump.outdoor_temperature_external.scaled_value
+        return self.heatpump.outdoor_temperature_external.reverse_scaled_value
     
     @property
     def pv_power(self) -> int:
@@ -442,7 +442,7 @@ class SolarfocusAPI:
             return False
         try:
             scaled = int(data_value.reverse_scale(value))
-            response = self._conn.write_registers(data_value.get_absolute_address(), [scaled], slave=self._slave_id)
+            response = self._conn.write_registers(data_value.get_absolute_address(), [scaled], unit=self._slave_id)
             if response.isError():
                 logging.error(f"Error writing value={value} to register: {data_value.get_absolute_address()}: {response}")
                 return False
@@ -459,7 +459,7 @@ class SolarfocusAPI:
         try:
             combined_result = [None] * component.holding_count
             for registerSlice in component.holding_slices:
-                result = self._conn.read_holding_registers(address=registerSlice.absolute_address,count=registerSlice.count ,slave=self._slave_id)
+                result = self._conn.read_holding_registers(address=registerSlice.absolute_address,count=registerSlice.count ,unit=self._slave_id)
                 if result.isError():
                     logging.error(f"Modbus read error at address={registerSlice.absolute_address}: {result}")
                     return False, None
@@ -478,7 +478,7 @@ class SolarfocusAPI:
         try:
             combined_result = [None] * component.input_count
             for registerSlice in component.input_slices:
-                result = self._conn.read_input_registers(address=registerSlice.absolute_address,count=registerSlice.count,slave=self._slave_id)
+                result = self._conn.read_input_registers(address=registerSlice.absolute_address,count=registerSlice.count,unit=self._slave_id)
                 if result.isError():
                     logging.error(f"Modbus read error at address={registerSlice.absolute_address}, count={registerSlice.count}: {result}")
                     return False, None
